Class: Anypost::Resources::Identity
- Defined in:
- lib/anypost/resources/identity.rb
Overview
Identity operations (‘/whoami`).
Instance Method Summary collapse
-
#whoami ⇒ Object
Identify the team and permission level behind the current API key.
Methods inherited from Base
Constructor Details
This class inherits a constructor from Anypost::Resources::Base
Instance Method Details
#whoami ⇒ Object
Identify the team and permission level behind the current API key.
8 9 10 |
# File 'lib/anypost/resources/identity.rb', line 8 def whoami request_object(:get, "/whoami") end |